/* ----------------------------------------------------------------------------
                                       spi.c

     Impelentierung eines SPI Interfaces

     MCU : stm8s103 / s003

     06.07.2017   R. seelig
   ---------------------------------------------------------------------------- */
/* ----------------------------------------------------------------------------
                                  Pinbelegungen:

     in "spi.h" :       IC-Pin    Dev-Board Pin

          mosi --- PC6   (16)         D11
          miso --- PC7   (17)         D12
          sck  --- PC5   (15)         D13
          res  --- PD4   ( 1)         D7

   ---------------------------------------------------------------------------- */
#include "spi.h"

#define SPI_DDR               PC_DDR
#define SPI_CR1S              PC_CR1
#define SPI_MISO_PIN          PC7
#define SPI_MOSI_PIN          PC6
#define SPI_CLK_PIN           PC5

uint8_t sck_dur;

void my_delay(unsigned int dt)
{
  if (!dt) return;

  while(dt)
  {

    __asm
      nop
    __endasm;

    dt--;
  }
}

uint8_t spi_set_sck_duration(uint8_t dur)
{
    sck_dur= dur;
    return(sck_dur);
}

uint8_t spi_get_sck_duration(void)
{
  return(sck_dur);
}

void spi_sck_pulse(void)
{
//  if (!sck_dur) durled_on();
  sck_clr();
//  my_delay(sck_dur);
  sck_set();
//  my_delay(sck_dur);
  sck_clr();
}

void spi_reset_pulse(void)
{
  reset_set();
  delay(4);
  reset_clr();
  delay(4);
}

void spi_init(void)
{
  mosi_init();
  miso_init();
  sck_init();
  reset_init();

  reset_set();
  mosi_clr();
  sck_clr();
  delay(4);

  reset_clr();
  delay(4);
  spi_reset_pulse();

//  durled_init();
//  durled_off();
}

// send 8 bit, return received byte
uint8_t spi_mastertransmit(uint8_t data)
{
  uint8_t i= 0x80;
  uint8_t rval= 0;

  // software spi
  sck_clr();

  while(i)
  {
    // MOSI
    if (data & i) mosi_set(); else mosi_clr();
    my_delay(1);
    // read MISO

    if( miso_isbit() )  rval|= i;

    sck_set();
    my_delay(1);
    sck_clr();
    i= i >> 1;
  }
  return(rval);
}

// send 16 bit, return last rec byte
uint8_t spi_mastertransmit_16(uint16_t data)
{
  spi_mastertransmit((data >> 8) & 0xff);

  return(spi_mastertransmit(data & 0xff));
}

// send 32 bit, return last rec byte
uint8_t spi_mastertransmit_32(uint32_t data)
{
  spi_mastertransmit((data >> 24) & 0xff);
  spi_mastertransmit((data >> 16) & 0xff);
  spi_mastertransmit((data >> 8) & 0xff);

  return(spi_mastertransmit(data & 0xff));
}

