/* ----------------------------------------------------------------------------
                                       spi.h

     Header fuer Sofwareimpelentierung (Bitbanging) eines SPI Interfaces

     MCU : stm8s103 / s003

     06.07.2017   R. seelig
   ---------------------------------------------------------------------------- */
/* ----------------------------------------------------------------------------
                                  Pinbelegungen:

     in "spi.h" :       IC-Pin    Dev-Board Pin

          mosi --- PC6   (16)         D11
          miso --- PC7   (17)         D12
          sck  --- PC5   (15)         D13
          res  --- PD4   ( 1)         D7

   ---------------------------------------------------------------------------- */
#ifndef in_spi_h
  #define in_spi_h

  #include "stm8s.h"
  #include "stm8_init.h"
  #include "stm8_gpio.h"

  #define mosi_init()    PC6_output_init()
  #define miso_init()    PC7_input_init()
  #define sck_init()     PC5_output_init()
  #define reset_init()   PD4_output_init()

  #define mosi_set()     PC6_set()
  #define mosi_clr()     PC6_clr()
  #define sck_set()      PC5_set()
  #define sck_clr()      PC5_clr()
  #define reset_set()    PD4_set()
  #define reset_clr()    PD4_clr()

  #define miso_isbit()   is_PC7()

  #define spi_disable()  { PC6_input_init(); PC5_input_init(); PC7_input_init(); }


//  #define durled_init()  ( PB1_output_init() )
//  #define durled_on()    ( PB1_clr() )               // gegen +Ub geschaltet
//  #define durled_off()   ( PB1_set() )


  void my_delay(unsigned int dt);

  void spi_init(void);
  uint8_t spi_set_sck_duration(uint8_t dur);
  uint8_t spi_get_sck_duration(void);
  uint8_t spi_mastertransmit(uint8_t data);
  uint8_t spi_mastertransmit_16(uint16_t data);
  uint8_t spi_mastertransmit_32(uint32_t data);
  void spi_reset_pulse(void);
  void spi_sck_pulse(void);

#endif        // in_spi_h
